@@ -358,6 +358,24 @@ def plot_ts(x, timestamps=None, ax=None, **kwargs):
     return ax
 
 
+def pairs(x, **kwargs):
+    """
+    Return a pairs plot of the data in x.
+
+    Args:
+      x: A pd.DataFrame or numpy matrix.
+
+    Returns:
+      The seaborn.axisgrid.PairGrid object containing the plots.
+    """
+    import seaborn as sns
+    if isinstance(x, np.ndarray):
+        x = pd.DataFrame(x)
+    ans = sns.pairplot(x, **kwargs)
+    ans.fig.show()
+    return ans
+
+
 # ===========================================================================
 # Custom plots
 # ===========================================================================
@@ -374,7 +392,8 @@ def mosaic_plot(counts, ax=None, col_vname=None, row_vname=None):
     else:
         fig = None
 
-    assert isinstance(ax, plt.Axes)
+    if not isinstance(ax, plt.Axes):
+        raise Exception("ax must be a plt.Axes object")
 
     if isinstance(counts, np.ndarray):
         counts = pd.DataFrame(counts,
@@ -644,6 +663,10 @@ def plot_dynamic_distribution(
     return ax
 
 
+# Allow the same function name as R.
+PlotDynamicDistribution = plot_dynamic_distribution
+
+
 def compare_dynamic_distributions(
         list_of_curves,
         timestamps,
