@@ -7,6 +7,7 @@
 #include "Models/Glm/Glm.hpp"
 #include "Models/Glm/GlmCoefs.hpp"
 #include "Models/Glm/RegressionModel.hpp"
+#include "Models/Glm/IndependentRegressionModels.hpp"
 #include "Models/Glm/TRegression.hpp"
 #include "Models/Glm/LoglinearModel.hpp"
 #include "Models/Glm/BinomialLogitModel.hpp"
@@ -15,6 +16,8 @@
 #include "Models/Glm/VariableSelectionPrior.hpp"
 
 #include "Models/Glm/PosteriorSamplers/BregVsSampler.hpp"
+#include "Models/Glm/PosteriorSamplers/RegressionConjSampler.hpp"
+#include "Models/Glm/PosteriorSamplers/IndependentRegressionModelsPosteriorSampler.hpp"
 #include "Models/Glm/PosteriorSamplers/TRegressionSpikeSlabSampler.hpp"
 #include "Models/Glm/PosteriorSamplers/BinomialLogitSpikeSlabSampler.hpp"
 #include "Models/Glm/PosteriorSamplers/PoissonRegressionSpikeSlabSampler.hpp"
@@ -50,8 +53,8 @@ namespace BayesBoom {
                 const std::vector<uint> &nonzero_positions) {
                coefs.set_sparse_coefficients(nonzero_values, nonzero_positions);
              },
-             "Set a specific set of coefficients to nonzero values, setting all "
-             "others to zero.")
+             "Set a specific set of coefficients to nonzero values, "
+             "setting all others to zero.")
         ;
 
     // A single data point for a regression model.
@@ -114,9 +117,12 @@ namespace BayesBoom {
         .def("add_all", &GlmModel::add_all)
         .def("drop_all", &GlmModel::drop_all)
         .def("drop_all_but_intercept", &GlmModel::drop_all_but_intercept)
-        .def("add", &GlmModel::add, "Add the variable in the specified position.")
-        .def("drop", &GlmModel::add, "Drop the variable in the specified position.")
-        .def("flip", &GlmModel::add, "Flip the variable in the specified position.")
+        .def("add", &GlmModel::add,
+             "Add the variable in the specified position.")
+        .def("drop", &GlmModel::add,
+             "Drop the variable in the specified position.")
+        .def("flip", &GlmModel::add,
+             "Flip the variable in the specified position.")
         .def_property_readonly(
             "coef",
             [](const GlmModel &m) {return m.coef();},
@@ -158,10 +164,10 @@ namespace BayesBoom {
              "Args:"
              "  X:  boom.Matrix of predictor variables.\n"
              "  y:  boom.Vector of responses.\n"
-             "  start_at_mle: If True then the model parameters will be initialized "
-             "to the maximum likelihood estimate (which will be undefined if X is "
-             "less than full rank).  If False then model parameters begin at "
-             "default levels.")
+             "  start_at_mle: If True then the model parameters will be "
+             "initialized to the maximum likelihood estimate (which will "
+             "be undefined if X is less than full rank).  If False then "
+             "model parameters begin at default levels.")
         .def_property_readonly(
             "suf",
             [](const RegressionModel &m) {return m.suf();},
@@ -171,14 +177,17 @@ namespace BayesBoom {
             [](RegressionModel &m) {
               return m.Sigsq_prm();
             },
-            "The parameter object representing the residual variance.  boom.UnivParams")
+            "The parameter object representing the residual variance.  "
+            "boom.UnivParams")
         .def_property_readonly(
             "coefficients",
             [](RegressionModel &m) {
               return m.coef();
             },
-            "The parameter object representing the model coefficients.  boom.GlmCoefs")
-        .def("set_coefficients", [](RegressionModel &m, const Vector &coefficients) {
+            "The parameter object representing the model coefficients.  "
+            "boom.GlmCoefs")
+        .def("set_coefficients", [](RegressionModel &m,
+                                    const Vector &coefficients) {
           m.set_Beta(coefficients);
         })
         .def_property_readonly(
@@ -199,6 +208,84 @@ namespace BayesBoom {
              })
         ;
 
+    py::class_<IndependentRegressionModels,
+               PriorPolicy,
+               PosteriorModeModel,
+               Ptr<IndependentRegressionModels>>(
+                   boom,
+                   "IndependentRegressionModels",
+                   py::multiple_inheritance())
+        .def(py::init(
+            [](int xdim, int ydim) {
+              return new IndependentRegressionModels(xdim, ydim);
+            }),
+             py::arg("xdim"),
+             py::arg("ydim"),
+             "Args:\n\n"
+             "  xdim:  Dimension of the predictors (X).\n"
+             "  ydim:  Dimension of the output/response (Y).\n")
+        .def("model",
+             [](IndependentRegressionModels *model, int which_model) {
+               return model->model(which_model);
+             },
+             py::arg("which_model"),
+             "Args:\n\n"
+             "  which_model:  The index (0, ... ydim-1) of the "
+             "component model.\n")
+        ;
+
+    py::class_<IndependentGlms<TRegressionModel>,
+               PriorPolicy,
+               Ptr<IndependentGlms<TRegressionModel>>>(
+                   boom,
+                   "IndependentStudentRegressions",
+                   py::multiple_inheritance())
+        .def(py::init(
+            [](int xdim, int ydim) {
+              return new IndependentGlms<TRegressionModel>(
+                  xdim, ydim);
+            }),
+             py::arg("xdim"),
+             py::arg("ydim"),
+             "Args:\n\n"
+             "  xdim:  Dimension of the predictors (X).\n"
+             "  ydim:  Dimension of the output/response (Y).\n")
+        .def("model",
+             [](IndependentGlms<TRegressionModel> *model, int which_model) {
+               return model->model(which_model);
+             },
+             py::arg("which_model"),
+             "Args:\n\n"
+             "  which_model:  The index (0, ... ydim-1) of the "
+             "component model.\n")
+        ;
+
+    py::class_<IndependentGlms<CompleteDataStudentRegressionModel>,
+               PriorPolicy,
+               Ptr<IndependentGlms<CompleteDataStudentRegressionModel>>>(
+                   boom,
+                   "IndependentStudentCompleteDataRegressions",
+                   py::multiple_inheritance())
+        .def(py::init(
+            [](int xdim, int ydim) {
+              return new IndependentGlms<CompleteDataStudentRegressionModel>(
+                  xdim, ydim);
+            }),
+             py::arg("xdim"),
+             py::arg("ydim"),
+             "Args:\n\n"
+             "  xdim:  Dimension of the predictors (X).\n"
+             "  ydim:  Dimension of the output/response (Y).\n")
+        .def("model",
+             [](IndependentGlms<CompleteDataStudentRegressionModel> *model, int which_model) {
+               return model->model(which_model);
+             },
+             py::arg("which_model"),
+             "Args:\n\n"
+             "  which_model:  The index (0, ... ydim-1) of the "
+             "component model.\n")
+        ;
+
     py::class_<RegressionSlabPrior,
                MvnBase,
                Ptr<RegressionSlabPrior>>(
@@ -284,7 +371,8 @@ namespace BayesBoom {
             [](BigRegressionModel &m) {
               return m.Sigsq_prm();
             },
-            "The parameter object representing the residual variance.  boom.UnivParams")
+            "The parameter object representing the residual variance.  "
+            "boom.UnivParams")
         ;
 
     py::class_<TRegressionModel,
@@ -325,14 +413,17 @@ namespace BayesBoom {
             [](TRegressionModel &m) {
               return m.Sigsq_prm();
             },
-            "The parameter object representing the residual variance.  boom.UnivParams")
+            "The parameter object representing the residual variance.  "
+            "boom.UnivParams")
         .def_property_readonly(
             "coefficients",
             [](TRegressionModel &m) {
               return m.coef();
             },
-            "The parameter object representing the model coefficients.  boom.GlmCoefs")
-        .def("set_coefficients", [](TRegressionModel &m, const Vector &coefficients) {
+            "The parameter object representing the model coefficients.  "
+            "boom.GlmCoefs")
+        .def("set_coefficients", [](TRegressionModel &m,
+                                    const Vector &coefficients) {
           m.set_Beta(coefficients);
         })
         .def_property_readonly(
@@ -349,6 +440,22 @@ namespace BayesBoom {
         })
         ;
 
+    py::class_<CompleteDataStudentRegressionModel,
+               TRegressionModel,
+               Ptr<CompleteDataStudentRegressionModel>>(
+                   boom,
+                   "CompleteDataStudentRegressionModel",
+                   py::multiple_inheritance())
+        .def(py::init(
+            [] (int xdim) {
+              return new CompleteDataStudentRegressionModel(xdim);
+            }),
+             py::arg("xdim"),
+             "Args:\n\n"
+             "  xdim:  Dimension of the predictor vector.\n")
+        ;
+
+
     py::class_<BinomialLogitModel,
                GlmModel,
                PriorPolicy,
@@ -447,39 +554,140 @@ namespace BayesBoom {
         ;
 
 
-    //===========================================================================
+    //=========================================================================
     // Priors and posterior samplers.
-    //===========================================================================
+    //=========================================================================
     py::class_<VariableSelectionPrior,
                Ptr<VariableSelectionPrior>>(boom, "VariableSelectionPrior")
         .def(py::init<const Vector &>(),
              py::arg("prior_inclusion_probabilities"),
-             "Create a VariableSelectionPrior from a vector of prior inclusion probabilities.\n\n"
+             "Create a VariableSelectionPrior from a vector of prior "
+             "inclusion probabilities.\n\n"
              "Args:\n\n"
-             "  prior_inclusion_probabilities: boom.Vector containing the prior "
-             "probability that each variable is to be included. "
+             "  prior_inclusion_probabilities: boom.Vector containing the "
+             "prior probability that each variable is to be included. "
              )
         ;
 
+    py::class_<RegressionConjugateSampler,
+               PosteriorSampler,
+               Ptr<RegressionConjugateSampler>>(
+                   boom, "RegressionConjugateSampler")
+        .def(py::init(
+            [](RegressionModel *model,
+               MvnGivenScalarSigmaBase *coefficient_prior,
+               GammaModelBase *residual_precision_prior,
+               RNG &seeding_rng) {
+              return new RegressionConjugateSampler(
+                  model,
+                  coefficient_prior,
+                  residual_precision_prior,
+                  seeding_rng);
+            }),
+             py::arg("model"),
+             py::arg("coefficient_prior"),
+             py::arg("residual_precision_prior"),
+             py::arg("seeding_rng") = BOOM::GlobalRng::rng,
+             "Args:\n\n"
+             "  model:  The regression model to be sampled.\n"
+             "  coefficient_prior:  A conditionally Gaussian prior for the "
+             "regression coefficients.\n"
+             "  residual_precision_prior:  Prior distribution for the "
+             "residual precision parameter.\n"
+             "  seeding_rng:  The random number generator used to set the seed "
+             "of the RNG owned by this sampler."
+             )
+        .def("set_sigma_upper_limit",
+             [](RegressionConjugateSampler *sampler,
+                double sigma_max) {
+               sampler->set_sigma_upper_limit(sigma_max);
+             },
+             py::arg("sigma_max"),
+             "Truncate the support of the residual standard deviation "
+             "parameter to (0, sigma_max).\n")
+        ;
+
+    py::class_<IndependentRegressionModelsPosteriorSampler,
+               PosteriorSampler,
+               Ptr<IndependentRegressionModelsPosteriorSampler>>(
+                   boom, "IndependentRegressionModelsPosteriorSampler")
+        .def(py::init(
+            [](IndependentRegressionModels *model,
+               RNG &seeding_rng) {
+              return new IndependentRegressionModelsPosteriorSampler(
+                  model, seeding_rng);
+            }),
+             py::arg("model"),
+             py::arg("seeding_rng") = BOOM::GlobalRng::rng,
+             "Args:\n\n"
+             "  model:  The model to be sampled.\n"
+             "  seeding_rng:  The RNG used to initialize the RNG owned by "
+             "this object.\n")
+        ;
+
+    py::class_<IndependentGlmsPosteriorSampler<TRegressionModel>,
+               PosteriorSampler,
+               Ptr<IndependentGlmsPosteriorSampler<TRegressionModel>>>(
+                   boom,
+                   "IndependentStudentRegressionsPosteriorSampler",
+                   py::multiple_inheritance())
+        .def(py::init(
+            [](IndependentGlms<TRegressionModel> *model,
+               RNG &seeding_rng) {
+              return new IndependentGlmsPosteriorSampler<
+                TRegressionModel>(model, seeding_rng);
+            }),
+             py::arg("model"),
+             py::arg("seeding_rng") = BOOM::GlobalRng::rng,
+             "Args:\n\n"
+             "  model:  The model to be sampled.\n"
+             "  seeding_rng:  The RNG used to initialize the RNG owned by "
+             "this object.\n")
+        ;
+
+    py::class_<IndependentGlmsPosteriorSampler<CompleteDataStudentRegressionModel>,
+               PosteriorSampler,
+               Ptr<IndependentGlmsPosteriorSampler<CompleteDataStudentRegressionModel>>>(
+                   boom,
+                   "IndependentCompleteDataStudentRegressionsPosteriorSampler",
+                   py::multiple_inheritance())
+        .def(py::init(
+            [](IndependentGlms<CompleteDataStudentRegressionModel> *model,
+               RNG &seeding_rng) {
+              return new IndependentGlmsPosteriorSampler<
+                CompleteDataStudentRegressionModel>(model, seeding_rng);
+            }),
+             py::arg("model"),
+             py::arg("seeding_rng") = BOOM::GlobalRng::rng,
+             "Args:\n\n"
+             "  model:  The model to be sampled.\n"
+             "  seeding_rng:  The RNG used to initialize the RNG owned by "
+             "this object.\n")
+        ;
+
     py::class_<BregVsSampler,
                PosteriorSampler,
                Ptr<BregVsSampler>>(boom, "BregVsSampler")
         .def(py::init(
-            [](Ptr<RegressionModel> model,
-               const Ptr<MvnGivenScalarSigma> &slab,
-               const Ptr<GammaModelBase> &residual_precision_prior,
-               const Ptr<VariableSelectionPrior> &spike,
+            [](RegressionModel *model,
+               MvnGivenScalarSigma *slab,
+               GammaModelBase *residual_precision_prior,
+               VariableSelectionPrior *spike,
                RNG &seeding_rng) {
-              return new BregVsSampler(model.get(), slab, residual_precision_prior,
-                                       spike, seeding_rng);
+              return new BregVsSampler(
+                  model,
+                  Ptr<MvnGivenScalarSigma>(slab),
+                  Ptr<GammaModelBase>(residual_precision_prior),
+                  Ptr<VariableSelectionPrior>(spike),
+                  seeding_rng);
             }),
              py::arg("model"),
              py::arg("slab"),
              py::arg("residual_precision_prior"),
              py::arg("spike"),
              py::arg("seeding_rng") = BOOM::GlobalRng::rng,
-             "Create a BregVsSampler -- a spike and slab sampler for regression "
-             "models.\n\n"
+             "Create a BregVsSampler -- a spike and slab sampler for "
+             "regression models.\n\n"
              "Args:\n"
              "  model:  The model to be sampled.\n"
              "  slab:  The conditional normal prior on the regression "
@@ -493,6 +701,55 @@ namespace BayesBoom {
              )
         ;
 
+    py::class_<TRegressionSampler,
+               PosteriorSampler,
+               Ptr<TRegressionSampler>>(
+                   boom,
+                   "TRegressionSampler",
+                   py::multiple_inheritance())
+        .def(py::init(
+            [](TRegressionModel *model,
+               MvnBase *coefficient_prior,
+               GammaModelBase *siginv_prior,
+               DoubleModel *tail_thickness_prior,
+               RNG &seeding_rng) {
+              return new TRegressionSampler(
+                  model,
+                  coefficient_prior,
+                  siginv_prior,
+                  tail_thickness_prior,
+                  seeding_rng);
+            }),
+             py::arg("model"),
+             py::arg("coefficient_prior"),
+             py::arg("siginv_prior"),
+             py::arg("tail_thickness_prior"),
+             py::arg("seeding_rng") = GlobalRng::rng,
+            "Args:\n\n"
+             "  model: The boom.TRegressionModel that the sampler will simulate"
+             " for.\n"
+             "  coefficient_prior:  A boom.MvnBase object giving the prior "
+             "distribution on the regression coefficients\n"
+            "  residual_precision_prior: A boom.GammaModelBase giving the "
+            "prior distribution on the residual precision parameter (one "
+            "over the residual variance).\n"
+            "  tail_thickness_prior: A boom.DoubleModel with support on "
+            "a subset of the positive real line.\n"
+             "  seeding_rng:  The random number generator used to set the seed "
+             "of the RNG owned by this sampler.")
+        .def("set_sigma_upper_limit",
+             [](TRegressionSampler *sampler,
+                double sigma_max) {
+               sampler->set_sigma_upper_limit(sigma_max);
+             },
+             py::arg("sigma_max"),
+             "Truncate the support of the residual standard deviation "
+             "parameter to (0, sigma_max).\n\n"
+             "Args:\n\n"
+             "  sigma_max:  Any non-negative value, including zero and "
+             "infinity() is allowed.")
+        ;
+
     py::class_<TRegressionSpikeSlabSampler,
                PosteriorSampler,
                Ptr<TRegressionSpikeSlabSampler>>(
@@ -513,7 +770,7 @@ namespace BayesBoom {
             py::arg("spike"),
             py::arg("residual_precision_prior"),
             py::arg("tail_thickness_prior"),
-            py::arg("rng"),
+            py::arg("seeding_rng"),
             "Args:\n\n"
             "  model: The boom.TRegressionModel that the sampler will simulate "
             "for.\n"
@@ -526,7 +783,9 @@ namespace BayesBoom {
             "over the residual variance).\n"
             "  tail_thickness_prior: A boom.DoubleModel with support on "
             "a subset of the positive real line.\n"
-             "  rng: A boom.RNG random number generator.\n")
+             "  seeding_rng:  The random number generator used to set the seed "
+             "of the RNG owned by this sampler."
+             )
         .def("set_sigma_upper_limit",
              [](TRegressionSpikeSlabSampler *sampler, double upper_limit) {
                sampler->set_sigma_upper_limit(upper_limit);
@@ -566,8 +825,8 @@ namespace BayesBoom {
              "  model:  The boom.BinomialLogitModel to be sampled.\n"
              "  slab: A boom.MvnBase prior for the conditional distribution of "
              "the regression coefficients given inclusion.\n"
-             "  spike:  A boom.VariableSelectionPrior describing which variables"
-             " are included in the model.\n"
+             "  spike:  A boom.VariableSelectionPrior describing which "
+             "variables are included in the model.\n"
              "  clt_threshold:  See below.\n"
              "  seeding_rng:  The random number generator used to set the seed "
              "of the RNG owned by this sampler.\n\n"
@@ -607,8 +866,8 @@ namespace BayesBoom {
              "  model:  The boom.PoissonRegressionModel to be sampled.\n"
              "  slab: A boom.MvnBase prior for the conditional distribution of "
              "the regression coefficients given inclusion.\n"
-             "  spike:  A boom.VariableSelectionPrior describing which variables"
-             " are included in the model.\n"
+             "  spike:  A boom.VariableSelectionPrior describing which "
+             "variables are included in the model.\n"
              "  num_threads:  The number of threads to use when imputing "
              "latent data.\n"
              "  seeding_rng:  The random number generator used to set the seed "
@@ -634,7 +893,8 @@ namespace BayesBoom {
                          GammaModelBase *residual_precision_prior,
                          RNG &seeding_rng){
                         return new BigAssSpikeSlabSampler(
-                            model, global_spike, slab_prototype, residual_precision_prior, seeding_rng);
+                            model, global_spike, slab_prototype,
+                            residual_precision_prior, seeding_rng);
                       }),
              py::arg("model"),
              py::arg("global_spike"),
@@ -643,9 +903,10 @@ namespace BayesBoom {
              py::arg("seeding_rng_") = BOOM::GlobalRng::rng,
              "Args:\n\n"
              "  model:  The boom.BigRegressionModel to be sampled.\n"
-             "  global_spike:  A boom.VariableSelectionPrior describing which variables"
-             " are included in the model.\n"
-             "  slab_prototype: A boom.RegressionSlabPrior prior for the conditional distribution of "
+             "  global_spike:  A boom.VariableSelectionPrior describing which "
+             "variables are included in the model.\n"
+             "  slab_prototype: A boom.RegressionSlabPrior prior for the "
+             "conditional distribution of "
              "the regression coefficients given inclusion.\n"
              "  seeding_rng:  The random number generator used to set the seed "
              "of the RNG owned by this sampler.\n"
@@ -661,8 +922,9 @@ namespace BayesBoom {
              "Args:\n\n"
              "  niter:  The number of MCMC iterations to use in the initial "
              "screen.\n"
-             "  threshold: The variables whose 'marginal inclusion probabilities'"
-             "exceed 'threshold' become candidates in the next round.\n"
+             "  threshold: The variables whose 'marginal inclusion "
+             " probabilities' exceed 'threshold' become candidates "
+             "in the next round.\n"
              "  use_threads: If 'True' then C++11 threads will be used to run "
              "the MCMC algorithms for the subordinate models.  If 'False' then "
              "the code path for doing the MCMC will not use threads.\n")
