@@ -7,7 +7,8 @@ import BayesBoom.spikeslab as ss
 import BayesBoom.R as R
 import matplotlib.pyplot as plt
 
-import pdb
+# pylint: disable=unused-import
+import pdb  # noqa
 
 
 class TestDynamicRegression(unittest.TestCase):
@@ -118,11 +119,9 @@ class TestDynamicRegression(unittest.TestCase):
 _debug_mode = False
 
 if _debug_mode:
-    import pdb  # noqa
-
     # Turn warnings into errors.
-#    import warnings
-#    warnings.simplefilter("error")
+    #    import warnings
+    #    warnings.simplefilter("error")
 
     # Run the test you are trying to debug here.  Instantiate the test class,
     # then call the problematic test.  Call pdb.pm() in the event of an
