@@ -26,7 +26,7 @@ class MlogitTest(unittest.TestCase):
         self.assertIsInstance(model, mlogit_spike)
 
 
-_debug_mode = True
+_debug_mode = False
 
 if _debug_mode:
     import pdb  # noqa
